SendSyncPtr

Struct SendSyncPtr 

pub(crate) struct SendSyncPtr(NonNull<c_void>);
Wrapper type to only mark a raw pointer Send + Sync without having to mark the entire Allocation as such, instead relying on the compiler to auto-implement this or fail if fields are added that violate this constraint

Tuple Fields

0: NonNull<c_void>