pub(crate) struct SendSyncPtr(NonNull<c_void>);Expand description
Wrapper type to only mark a raw pointer Send + Sync without having to
mark the entire Allocation as such, instead relying on the compiler to
auto-implement this or fail if fields are added that violate this constraint
Tuple Fields
0: NonNull<c_void>Trait Implementations
Sourceimpl Clone for SendSyncPtr
impl Clone for SendSyncPtr
Sourcefn clone(&self) -> SendSyncPtr
fn clone(&self) -> SendSyncPtr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendSyncPtr
impl Debug for SendSyncPtr
impl Copy for SendSyncPtr
impl Send for SendSyncPtr
impl Sync for SendSyncPtr